import 'package:flutter/cupertino.dart';
import 'package:flutter/material.dart';
import 'package:flutter_bloc/flutter_bloc.dart';
import 'package:modal_progress_hud/modal_progress_hud.dart';
import 'package:ocg_app/ocg_app.dart';
import 'package:ocg_login/ocg_login.dart';

class EmailSignInScreen extends StatefulWidget {
  EmailSignInScreen({Key key}) : super(key: key);

  @override
  _EmailSignInScreenState createState() => _EmailSignInScreenState();
}

class _EmailSignInScreenState extends State<EmailSignInScreen> {
  final GlobalKey<FormState> _key = GlobalKey<FormState>();
  final GlobalKey<ScaffoldState> _scaffoldKey = GlobalKey<ScaffoldState>();
  String _email, _password;

  @override
  void didChangeDependencies() {
    super.didChangeDependencies();
    BlocProvider.of<LoginBloc>(context).add(LoginCheckEvent());
  }

  @override
  Widget build(BuildContext context) {
    return Scaffold(
      key: _scaffoldKey,
      appBar: AppBar(),
      body: BlocListener<LoginBloc, LoginState>(
        listener: (context, state) {
          if (state is LoginSuccessState) {
            _scaffoldKey.currentState
                .showSnackBar(SnackBar(content: Text("Logged in succes")));
          } else if (state is LoginErrorState) {
            _scaffoldKey.currentState
                .showSnackBar(SnackBar(content: Text(state.error)));
          }
        },
        child:
            BlocBuilder<LoginBloc, LoginState>(builder: (context, loginState) {
          return ModalProgressHUD(
            inAsyncCall: loginState is LoginLoadingState,
            child: Form(
                key: _key,
                child: Column(
                  mainAxisSize: MainAxisSize.min,
                  children: [
                    TextFormField(
                      decoration: InputDecoration(labelText: "Email"),
                      validator: (val) =>
                          InputHelper.validateMessage("Email", val),
                      onChanged: (val) {
                        setState(() {
                          _email = val;
                        });
                      },
                    ),
                    SizedBox(
                      height: 12,
                    ),
                    TextFormField(
                      decoration: InputDecoration(labelText: "Password"),
                      validator: (val) =>
                          InputHelper.validateMessage("Password", val),
                      onChanged: (val) {
                        setState(() {
                          _password = val;
                        });
                      },
                      obscureText: true,
                    ),
                    SizedBox(
                      height: 12,
                    ),
                    CupertinoButton(
                        child: Text("Signin"), onPressed: _signupEmailPassword)
                  ],
                )),
          );
        }),
      ),
    );
  }

  Future<void> _signupEmailPassword() async {
    BlocProvider.of<LoginBloc>(context)
        .add(LoginEmailSigninEvent(_email, _password));
  }
}
