import 'package:flutter/cupertino.dart';
import 'package:flutter/material.dart';
import 'package:flutter_bloc/flutter_bloc.dart';
import 'package:modal_progress_hud/modal_progress_hud.dart';
import 'package:ocg_app/ocg_app.dart';
import 'package:ocg_login/ocg_login.dart';

class MobileSigninScreen extends StatefulWidget {
  MobileSigninScreen({Key key}) : super(key: key);

  @override
  _MobileSigninScreenState createState() => _MobileSigninScreenState();
}

class _MobileSigninScreenState extends State<MobileSigninScreen> {
  final GlobalKey<FormState> _key = GlobalKey<FormState>();
  final GlobalKey<ScaffoldState> _scaffoldKey = GlobalKey<ScaffoldState>();
  String _mobile, _otp;
  bool _isOtpSent;

  @override
  void initState() {
    super.initState();
    _isOtpSent = false;
  }

  @override
  Widget build(BuildContext context) {
    return Scaffold(
      key: _scaffoldKey,
      appBar: AppBar(),
      body: BlocListener<LoginBloc, LoginState>(
        listener: (context, state) {
          if (state is LoginSuccessState) {
            _scaffoldKey.currentState
                .showSnackBar(SnackBar(content: Text("Logged in succes")));
          } else if (state is LoginErrorState) {
            _scaffoldKey.currentState
                .showSnackBar(SnackBar(content: Text(state.error)));
          } else if (state is LoginOTPNotVerifiedState) {
            setState(() {
              _isOtpSent = true;
            });
          }
        },
        child:
            BlocBuilder<LoginBloc, LoginState>(builder: (context, loginState) {
          return ModalProgressHUD(
            inAsyncCall: loginState is LoginLoadingState,
            child: Form(
                key: _key,
                child: Column(
                  mainAxisSize: MainAxisSize.min,
                  children: [
                    TextFormField(
                      enabled: !_isOtpSent,
                      decoration: InputDecoration(labelText: "Mobile"),
                      validator: (val) =>
                          InputHelper.validateMessage("Mobile", val),
                      onChanged: (val) {
                        setState(() {
                          _mobile = val;
                        });
                      },
                    ),
                    SizedBox(
                      height: 12,
                    ),
                    TextFormField(
                      enabled: _isOtpSent,
                      decoration: InputDecoration(labelText: "OTP"),
                      validator: (val) =>
                          InputHelper.validateMessage("OTP", val),
                      onChanged: (val) {
                        setState(() {
                          _otp = val;
                        });
                      },
                      obscureText: true,
                    ),
                    SizedBox(
                      height: 12,
                    ),
                    CupertinoButton(
                        child: Text(_isOtpSent ? "Verify OTP" : "Send OTP"),
                        onPressed: _isOtpSent ? _verifyOTP : _sendOTP)
                  ],
                )),
          );
        }),
      ),
    );
  }

  Future<void> _sendOTP() async {
    BlocProvider.of<LoginBloc>(context).add(LoginMobileEvent(null, _mobile));
  }

  Future<void> _verifyOTP() async {
    BlocProvider.of<LoginBloc>(context).add(LoginOTPEvent(_mobile, _otp));
  }
}
