import 'package:flutter/cupertino.dart';
import 'package:flutter/material.dart';
import 'package:flutter_bloc/flutter_bloc.dart';
import 'package:modal_progress_hud/modal_progress_hud.dart';
import 'package:ocg_login/ocg_login.dart';

class SocialLoginScreen extends StatefulWidget {
  SocialLoginScreen({Key key}) : super(key: key);

  @override
  _SocialLoginScreenState createState() => _SocialLoginScreenState();
}

class _SocialLoginScreenState extends State<SocialLoginScreen> {
  final GlobalKey<ScaffoldState> _scaffoldKey = GlobalKey<ScaffoldState>();

  @override
  Widget build(BuildContext context) {
    return Scaffold(
      key: _scaffoldKey,
      appBar: AppBar(),
      body: BlocListener<LoginBloc, LoginState>(
        listener: (context, state) {
          if (state is LoginSuccessState) {
            _scaffoldKey.currentState
                .showSnackBar(SnackBar(content: Text("Logged in succes")));
          } else if (state is LoginErrorState) {
            debugPrint("Error ${state.error}");
            _scaffoldKey.currentState
                .showSnackBar(SnackBar(content: Text(state.error)));
          }
        },
        child:
            BlocBuilder<LoginBloc, LoginState>(builder: (context, loginState) {
          return ModalProgressHUD(
            inAsyncCall: loginState is LoginLoadingState,
            child: Column(
              mainAxisSize: MainAxisSize.min,
              children: [
                RaisedButton(
                  onPressed: _signinWithGoogle,
                  child: Text("Google"),
                ),
                SizedBox(
                  height: 12,
                ),
                RaisedButton(
                  onPressed: _signinWithFacebook,
                  child: Text("Facebook"),
                ),
                SizedBox(
                  height: 12,
                ),
                RaisedButton(
                  onPressed: _signinWithApple,
                  child: Text("Apple"),
                ),
              ],
            ),
          );
        }),
      ),
    );
  }

  Future<void> _signinWithGoogle() async {
    BlocProvider.of<LoginBloc>(context).add(LoginGoogleSigninEvent());
  }

  Future<void> _signinWithFacebook() async {
    BlocProvider.of<LoginBloc>(context).add(LoginFacebookSigninEvent());
  }

  Future<void> _signinWithApple() async {
    BlocProvider.of<LoginBloc>(context).add(LoginAppleSigninEvent());
  }
}
