import 'package:flutter_bloc/flutter_bloc.dart';
import 'package:ocg_app/ocg_app.dart';
import 'package:ocg_login/ocg_login.dart';

abstract class ForgotPasswordEvent {}

class ForgotPasswordEmailEvent extends ForgotPasswordEvent {
  final String email;

  ForgotPasswordEmailEvent(this.email);
}

abstract class ForgotPasswordState {}

class ForgotPasswordInitialState extends ForgotPasswordState {}

class ForgotPasswordLoadingState extends ForgotPasswordState {}

class ForgotPasswordSuccessState extends ForgotPasswordState {
  ForgotPasswordSuccessState();
}

class ForgotPasswordErrorState extends ForgotPasswordState {
  final String error;
  ForgotPasswordErrorState(this.error);
}

class ForgotPasswordBloc
    extends Bloc<ForgotPasswordEvent, ForgotPasswordState> {
  final LoginRepository loginRepository;
  ForgotPasswordBloc(this.loginRepository)
      : super(ForgotPasswordInitialState());
  @override
  Stream<ForgotPasswordState> mapEventToState(
      ForgotPasswordEvent event) async* {
    if (event is ForgotPasswordEmailEvent) {
      yield ForgotPasswordLoadingState();
      AppResponse<bool> response =
          await loginRepository.sendResetPasswordEmail(event.email);
      if (response.isSuccess) {
        yield ForgotPasswordSuccessState();
      } else {
        yield ForgotPasswordErrorState(response.error);
      }
    }
  }
}
