import 'package:ocg_app/ocg_app.dart';
import 'package:flutter/material.dart';
import 'package:path_provider/path_provider.dart';
import 'package:sembast/sembast.dart';
import 'package:sembast/sembast_io.dart';
// import 'package:sembast_web/sembast_web.dart';
import 'package:flutter/foundation.dart' show kIsWeb;

class LoginDatabase {
  static const String _dbPath = 'user.db';
  static Database _db;
  static StoreRef _storeRef;
  static const String USER = "user";
  static const String TOKEN = "token";

  Future<void> open() async {
    if (_db != null) {
      return;
    }
    String path;
    if (kIsWeb) {
      path = "sample.db";
      // _db = await databaseFactoryWeb.openDatabase(path);
    } else {
      final appDocDir = await getApplicationDocumentsDirectory();
      path = "${appDocDir.path}/$_dbPath";
      _db = await databaseFactoryIo.openDatabase(path, version: 1);
    }
    _storeRef = StoreRef.main();
    return;
  }

  bool get isOpened => _db != null;

  Future<AppResponse<bool>> storeUser(String id) async {
    try {
      await _storeRef.record(USER).put(_db, id);
      return AppResponse.named(data: true);
    } catch (e) {
      debugPrint("Error $e");
      return AppResponse.named(error: "${e.toString()}");
    }
  }

  Future<AppResponse<String>> getUser() async {
    try {
      var result = await _storeRef.record(USER).get(_db) as String;
      if (result == null) {
        return AppResponse.named(error: "User does not exists");
      }
      return AppResponse.named(data: result);
    } catch (e) {
      debugPrint("Error $e");

      return AppResponse.named(error: "${e.toString()}");
    }
  }

  Future<AppResponse<bool>> saveToken(AppToken token) async {
    try {
      await _storeRef.record(TOKEN).put(_db, token.toJson());
      return AppResponse.named(data: true);
    } catch (e) {
      return AppResponse.named(error: "${e.toString()}");
    }
  }

  Future<AppResponse<AppToken>> getToken() async {
    try {
      var result = await _storeRef.record(TOKEN).get(_db);
      if (result == null) {
        return AppResponse.named(error: "Token does not exists");
      }
      return AppResponse.named(
          data: AppToken.fromJson(Map<String, dynamic>.from(result)));
    } catch (e) {
      debugPrint("Error $e");
      return AppResponse.named(error: "${e.toString()}");
    }
  }

  Future<AppResponse<bool>> deleteToken() async {
    try {
      await _storeRef.record(TOKEN).delete(_db);
      return AppResponse.named(data: true);
    } catch (e) {
      return AppResponse.named(error: "${e.toString()}");
    }
  }
}
