import 'dart:convert';

import 'package:flutter/material.dart';
import 'package:ocg_app/ocg_app.dart';
import 'package:ocg_login/src/repository/login/base.dart';
import 'package:ocg_login/src/repository/token.dart';
import 'package:http/http.dart' as http;
import 'package:sms_autofill/sms_autofill.dart';
import 'package:uuid/uuid.dart';

class LoginNetworkRepository extends LoginRepository {
  final LoginTokenRepository tokenRepository;
  final http.BaseClient client;

  LoginNetworkRepository(this.tokenRepository, this.client);

  @override
  Future<AppResponse<String>> sendOTP(
      String countryCode, String mobileNumber) async {
    String url = "/auth/code/send/";
    String hash;
    try {
      hash = await SmsAutoFill().getAppSignature;
    } catch (e) {}
    try {
      String realMobile = "$countryCode" + "$mobileNumber";
      var body = {"phone": realMobile, "device_hash": hash ?? ""};
      var response = await client.post(url,
          body: jsonEncode(body), headers: ApiConfig.headers);
      return AppResponse.named(
          data: realMobile, error: jsonDecode(response.body)["err"]);
    } catch (e) {
      debugPrint("Error $e");
      return AppResponse.named(error: e.toString());
    }
  }

  @override
  Future<AppResponse<AppToken>> verifyOTP(
      String mobileNumber, String otp) async {
    try {
      String url = "/auth/code/check/";
      var body = {"phone": "$mobileNumber", "code": otp};
      var response = await client.post(url,
          body: jsonEncode(body), headers: ApiConfig.headers);
      var json = jsonDecode(response.body);
      json["userId"] = json["user_id"];
      AppToken appToken = AppToken.fromJson(json);
      await tokenRepository.saveToken(appToken);
      AppResponse<AppToken> appResponse = await tokenRepository.getToken();

      return AppResponse.named(data: appResponse.data);
    } catch (e) {
      return AppResponse.named(error: e.toString());
    }
  }

  Future<AppResponse<bool>> verifyEmailPassword(
      String emailId, String password) async {
    try {
      String url = "/auth/email/verify/";
      var body = {"email": "$emailId", "password": password};
      var response = await client.post(url,
          body: jsonEncode(body), headers: ApiConfig.headers);
      var json = jsonDecode(response.body);
      json["userId"] = json["user_id"];
      AppToken appToken = AppToken.fromJson(json);
      await tokenRepository.saveToken(appToken);
      AppResponse<AppToken> appResponse = await tokenRepository.getToken();
      if (appResponse.isSuccess) {
        debugPrint("App Response ${appResponse.data}");
      }
      return AppResponse.named(data: true);
    } catch (e) {
      return AppResponse.named(error: e.toString());
    }
  }

  @override
  Future<AppResponse<bool>> isLoggedIn() async {
    try {
      String url = "/self";
      AppResponse<AppToken> response = await tokenRepository.getToken();
      await client.get(
        url,
      );
      return AppResponse.named(data: true);
    } catch (e) {
      return AppResponse.named(error: e.toString());
    }
  }

  @override
  Future<AppResponse<AppToken>> createUserWithEmailAndPassword(
      String email, String password) async {
    await Future.delayed(Duration(seconds: 1));
    AppToken token = AppToken.named(token: Uuid().v4(), userId: Uuid().v4());
    await tokenRepository.saveToken(token);
    return AppResponse.named(data: token);
  }

  @override
  Future<AppResponse<AppToken>> signInWithEmailAndPassword(
      String email, String password) {
    // TODO: implement signInWithEmailAndPassword
    throw UnimplementedError();
  }

  @override
  Future<AppResponse<AppToken>> signInWithFacebook() {
    // TODO: implement signInWithFacebook
    throw UnimplementedError();
  }

  @override
  Future<AppResponse<bool>> signOut() {
    // TODO: implement signOut
    throw UnimplementedError();
  }

  @override
  Future<AppResponse<AppToken>> signWithGoogle() {
    // TODO: implement signWithGoogle
    throw UnimplementedError();
  }

  @override
  Future<AppResponse<AppToken>> signInWithApple() {
    // TODO: implement signInWithApple
    throw UnimplementedError();
  }

  @override
  Future<AppResponse<AppToken>> getToken() async {
    return await tokenRepository.getToken();
  }

  @override
  Future<AppResponse<bool>> sendResetPasswordEmail(String email) {
    // TODO: implement sendResetPasswordEmail
    throw UnimplementedError();
  }
}
