import 'dart:async';

import 'package:flutter/cupertino.dart';
import 'package:flutter/material.dart';
import 'package:flutter/services.dart';
import 'package:flutter_bloc/flutter_bloc.dart';
import 'package:modal_progress_hud/modal_progress_hud.dart';
import 'package:ocg_app/ocg_app.dart';
import 'package:ocg_login/ocg_login.dart';
import 'package:ocg_login/src/screens/mobile_input_tab.dart';
import 'package:ocg_login/src/screens/otp_input_tab.dart';

import 'package:sms_autofill/sms_autofill.dart';

class LoginScreen extends StatefulWidget {
  @override
  _LoginScreenState createState() => _LoginScreenState();
}

class _LoginScreenState extends State<LoginScreen>
    with TickerProviderStateMixin<LoginScreen> {
  static const int MAX_COUNTER = 20;
  final GlobalKey<ScaffoldState> key = GlobalKey<ScaffoldState>();
  String otp;
  String mobileNumber;
  String countryCode;
  TextEditingController otpController;
  bool isOTPSent;
  bool isLoading;
  int counter = MAX_COUNTER;
  Timer timer;
  SmsAutoFill smsAutoFill;
  bool addNewUser;
  TabController tabController;

  @override
  void initState() {
    super.initState();
    tabController = TabController(length: 2, vsync: this);
    otpController = TextEditingController();
    otpController.addListener(() {
      if (!mounted) {
        return;
      }
      if (otpController.text != otp) {
        otp = otpController.text;
      }
    });
    isOTPSent = false;
    isLoading = false;
    smsAutoFill = SmsAutoFill();
    smsAutoFill.listenForCode;
    smsAutoFill.code.listen((val) {
      // Autofill
      if (val != null && mounted) {
        otpController.text = val;
        otp = val;
        setState(() {});
      }
    });
    WidgetsBinding.instance.addPostFrameCallback((duration) {
      var arguments = ModalRoute.of(context).settings.arguments;
      if (arguments != null && arguments is Map) {
        bool isAdd = arguments["add"];
        if (mounted) {
          setState(() {
            addNewUser = isAdd ?? false;
          });
        } else {
          if (mounted)
            setState(() {
              addNewUser = false;
            });
        }
      } else {
        if (mounted)
          setState(() {
            addNewUser = false;
          });
      }
    });
  }

  void initializeTimer() {
    if (mounted) {
      setState(() {
        counter = MAX_COUNTER;
      });
    }
    if (timer != null && timer.isActive) {
      timer.cancel();
    }
    timer = Timer.periodic(Duration(seconds: 1), (timer) {
      counter--;
      if (mounted) {
        setState(() {});
      } else {
        timer.cancel();
      }
      if (counter == 0) {
        timer.cancel();
      }
    });
  }

  @override
  Widget build(BuildContext context) {
    return WillPopScope(
      onWillPop: () async {
        return addNewUser ?? false;
      },
      child: AnnotatedRegion<SystemUiOverlayStyle>(
        value: SystemUiOverlayStyle.dark,
        child: BlocListener<LoginBloc, LoginState>(
          listener: (context, state) {
            if (state is LoginOTPNotVerifiedState) {
              initializeTimer();
              tabController.animateTo(1,
                  duration: Duration(
                    milliseconds: 200,
                  ),
                  curve: Curves.easeIn);
            }
            if (state is LoginSuccessState) {
              AppActionHandler.of(context).goHome();
            } else if (state is LoginErrorState) {
              key.currentState
                  .showSnackBar(SnackBar(content: Text("${state.error}")));
            }
          },
          child: BlocBuilder<LoginBloc, LoginState>(
              builder: (context, loginState) {
            return ModalProgressHUD(
              inAsyncCall: loginState is LoginLoadingState,
              child: Scaffold(
                appBar: (addNewUser ?? false) ? AppBar() : null,
                key: key,
                body: TabBarView(
                  physics: NeverScrollableScrollPhysics(),
                  children: [
                    MobileInputTab(
                      onSubmitted: (countryCode, mobileNumber) async {
                        this.countryCode = countryCode;
                        this.mobileNumber = mobileNumber;
                        setState(() {});
                        sendOTP();
                      },
                    ),
                    OTPInputTab(
                      onResend: () {
                        resendOTP();
                      },
                      onBack: () {
                        tabController.animateTo(0,
                            duration: Duration(
                              milliseconds: 200,
                            ),
                            curve: Curves.easeIn);
                      },
                      onVerify: (otp) {
                        this.otp = otp;
                        setState(() {});
                        verifyOTP();
                      },
                    ),
                  ],
                  controller: tabController,
                ),
              ),
            );
          }),
        ),
      ),
    );
  }

  Future<void> verifyOTP() async {
    BlocProvider.of<LoginBloc>(context).add(LoginOTPEvent(mobileNumber, otp));
  }

  String get realMobile => "+$countryCode$mobileNumber";

  ///
  /// Functions
  ///

  Future<void> sendOTP() async {
    BlocProvider.of<LoginBloc>(context)
        .add(LoginMobileEvent(countryCode, mobileNumber));
  }

  Future<void> resendOTP() async {
    otpController.text = '';
    BlocProvider.of<LoginBloc>(context)
        .add(LoginMobileEvent(countryCode, mobileNumber));
  }

  @override
  void dispose() {
    timer?.cancel();
    tabController.dispose();
    super.dispose();
  }
}
