import 'package:country_pickers/country.dart';
import 'package:country_pickers/country_pickers.dart';
import 'package:flutter/material.dart';
import 'package:flutter/services.dart';
import 'package:ocg_login/src/widgets/continue_button.dart';

class MobileInputTab extends StatefulWidget {
  final bool addNewUser;
  final Function(
    String countryCode,
    String mobileNumber,
  ) onSubmitted;

  const MobileInputTab({Key key, this.addNewUser = false, this.onSubmitted})
      : super(key: key);
  @override
  _MobileInputTabState createState() => _MobileInputTabState();
}

class _MobileInputTabState extends State<MobileInputTab> {
  final GlobalKey<ScaffoldState> key = GlobalKey<ScaffoldState>();
  final GlobalKey<FormState> formKey = GlobalKey<FormState>();
  Country _selectedCountry;
  String mobileNumber;
  TextEditingController editingController;
  FocusNode focusNode;

  initState() {
    super.initState();
    _selectedCountry = CountryPickerUtils.getCountryByIsoCode('IN');
    editingController = TextEditingController();
    focusNode = FocusNode();
  }

  @override
  Widget build(BuildContext context) {
    return Scaffold(
      body: SingleChildScrollView(
        child: SizedBox(
          height: MediaQuery.of(context).size.height,
          child: Padding(
            padding: const EdgeInsets.symmetric(vertical: 16, horizontal: 20),
            child: Column(
              mainAxisSize: MainAxisSize.min,
              crossAxisAlignment: CrossAxisAlignment.stretch,
              children: [
                Expanded(
                  child: Container(),
                  flex: 2,
                ),
                Hero(
                  tag: "Splash",
                  child: Container(
                    alignment: Alignment.center,
                    child: SizedBox(
                      child: FlutterLogo(),
                      width: MediaQuery.of(context).size.width / 2.5,
                      height: MediaQuery.of(context).size.width / 2.5,
                    ),
                  ),
                ),
                SizedBox(
                  height: 60,
                ),
                RichText(
                  text: TextSpan(children: [
                    TextSpan(
                      text: "Welcome,\n",
                      style: TextStyle(
                        color: Colors.black,
                        fontSize: 27,
                      ),
                    ),
                    TextSpan(
                      text: widget.addNewUser
                          ? "add new account"
                          : "Please enter your number.",
                      style: TextStyle(color: Colors.black54, fontSize: 22),
                    ),
                  ], style: TextStyle(fontWeight: FontWeight.w600)),
                ),
                SizedBox(
                  height: 48,
                ),
                Form(
                  key: formKey,
                  child: TextFormField(
                    controller: editingController,
                    decoration: InputDecoration(
                      labelText: "Mobile Number",
                      prefixIcon: _prefixIcon,
                    ),
                    focusNode: focusNode,
                    keyboardType: TextInputType.number,
                    inputFormatters: [
                      FilteringTextInputFormatter.digitsOnly,
                    ],
                    onChanged: (val) {
                      setState(() {
                        mobileNumber = val;
                      });
                    },
                  ),
                ),
                SizedBox(
                  height: 42,
                ),
                ContinueButton(
                  title: "Request OTP",
                  onPressed: () async {
                    if (!formKey.currentState.validate()) {
                      return;
                    }
                    // bool isValid = false;
                    // try {
                    //   isValid = await PhoneNumberUtil.isValidPhoneNumber(
                    //       phoneNumber: mobileNumber,
                    //       isoCode: _selectedCountry.isoCode);
                    // } catch (e) {}
                    // if (!isValid) {
                    //   return;
                    // }
                    widget.onSubmitted(
                      _selectedCountry.phoneCode,
                      mobileNumber,
                    );
                    focusNode.unfocus();
                  },
                  color: Theme.of(context).primaryColor,
                  textColor: Colors.white,
                ),
                SizedBox(
                  height: 24,
                ),
                Expanded(
                  flex: 3,
                  child: Container(),
                ),
                Text(
                  "© 2020 OCG Connect Inc. All rights reserved.",
                  style: TextStyle(
                      color: Colors.black54,
                      fontSize: 15,
                      fontWeight: FontWeight.w400),
                  textAlign: TextAlign.center,
                ),
                SizedBox(
                  height: 8,
                ),
              ],
            ),
          ),
        ),
      ),
    );
  }

  Widget get _prefixIcon => InkWell(
        onTap: _showPhoneCodes,
        child: Container(
          padding: EdgeInsets.symmetric(vertical: 8),
          margin: EdgeInsets.only(right: 12),
          width: 45,
          height: 45,
          alignment: Alignment.center,
          child: _selectedCountry != null
              ? Material(
                  elevation: 2.0,
                  child: SizedBox(
                      height: 16,
                      width: 24,
                      child: CountryPickerUtils.getDefaultFlagImage(
                          _selectedCountry)),
                )
              : Row(
                  children: <Widget>[
                    Text('Code'),
                    Icon(Icons.arrow_drop_down),
                  ],
                ),
        ),
      );

  Future _showPhoneCodes() async {
    showDialog(
      context: context,
      builder: (context) => CountryPickerDialog(
        titlePadding: EdgeInsets.all(8.0),
        searchInputDecoration: InputDecoration(hintText: 'Search...'),
        isSearchable: true,
        title: Text('Select your country'),
        onValuePicked: (Country country) {
          setState(
            () => _selectedCountry = country,
          );
        },
        itemFilter: (c) => true,
        itemBuilder: (country) {
          return Row(
            children: <Widget>[
              Expanded(child: Text(country.name)),
              SizedBox(width: 8.0),
              Material(
                elevation: 2.0,
                child: CountryPickerUtils.getDefaultFlagImage(country),
              ),
            ],
          );
        },
      ),
    );
  }
}
