import 'dart:async';

import 'package:flutter/cupertino.dart';
import 'package:flutter/material.dart';
import 'package:flutter/services.dart';
import 'package:ocg_app/ocg_app.dart';
import 'package:ocg_login/src/widgets/continue_button.dart';
import 'package:pinput/pin_put/pin_put.dart';
import 'package:sms_autofill/sms_autofill.dart';

class OTPInputTab extends StatefulWidget {
  final Function(String otp) onVerify;
  final Function() onResend;
  final Function() onBack;

  const OTPInputTab({Key key, this.onVerify, this.onResend, this.onBack})
      : super(key: key);
  @override
  _OTPInputTabState createState() => _OTPInputTabState();
}

class _OTPInputTabState extends State<OTPInputTab> {
  static const int MAX_COUNTER = 20;
  final GlobalKey<ScaffoldState> key = GlobalKey<ScaffoldState>();
  final GlobalKey<FormState> formKey = GlobalKey<FormState>();
  String otp;
  TextEditingController otpController;
  bool isOTPSent;
  bool isLoading;
  int counter = MAX_COUNTER;
  Timer timer;
  SmsAutoFill smsAutoFill;
  FocusNode focusNode;

  @override
  void initState() {
    super.initState();
    otpController = TextEditingController();

    isOTPSent = false;
    isLoading = false;
    smsAutoFill = SmsAutoFill();
    smsAutoFill.listenForCode;
    focusNode = FocusNode();
    smsAutoFill.code.listen((val) {
      if (val != null && mounted) {
        otpController.text = val;
        otp = val;
        setState(() {});
      }
    });
    WidgetsBinding.instance.addPostFrameCallback((duration) {
      initializeTimer();
    });
  }

  ///
  ///  Resend Timer
  ///
  void initializeTimer() {
    if (mounted) {
      setState(() {
        counter = MAX_COUNTER;
      });
    }
    if (timer != null && timer.isActive) {
      timer.cancel();
    }
    timer = Timer.periodic(Duration(seconds: 1), (timer) {
      counter--;
      if (mounted) {
        setState(() {});
      } else {
        timer.cancel();
      }
      if (counter == 0) {
        timer.cancel();
      }
    });
  }

  void resetOTP() {
    otpController.text = '';
    setState(() {
      isOTPSent = false;
    });
    widget.onResend();
  }

  @override
  Widget build(BuildContext context) {
    return AnnotatedRegion<SystemUiOverlayStyle>(
      value: SystemUiOverlayStyle.dark,
      child: Scaffold(
        key: key,
        body: SingleChildScrollView(
          child: Padding(
            padding: const EdgeInsets.all(8.0),
            child: Center(
                child: SizedBox(
              height: MediaQuery.of(context).size.height,
              child: SafeArea(
                child: Padding(
                  padding:
                      const EdgeInsets.symmetric(vertical: 12, horizontal: 24),
                  child: Column(
                    mainAxisSize: MainAxisSize.min,
                    crossAxisAlignment: CrossAxisAlignment.stretch,
                    children: <Widget>[
                      Expanded(
                        child: Container(),
                        flex: 2,
                      ),
                      Hero(
                        tag: "Splash",
                        child: Container(
                          alignment: Alignment.center,
                          child: SizedBox(
                            width: MediaQuery.of(context).size.width / 2.5,
                            height: MediaQuery.of(context).size.width / 2.5,
                            child: FlutterLogo(),
                          ),
                        ),
                      ),
                      SizedBox(
                        height: 36,
                      ),
                      RichText(
                        text: TextSpan(children: [
                          TextSpan(
                            text: "Verify OTP,\n",
                            style: TextStyle(
                              color: Colors.black,
                              fontSize: 27,
                            ),
                          ),
                          TextSpan(
                            text: "Enter the 6 digit OTP",
                            style:
                                TextStyle(color: Colors.black54, fontSize: 22),
                          ),
                        ], style: TextStyle(fontWeight: FontWeight.w600)),
                      ),
                      SizedBox(
                        height: 12,
                      ),
                      Container(
                        alignment: Alignment.centerLeft,
                        child: CupertinoButton(
                          onPressed: () {
                            widget.onBack();
                          },
                          minSize: 0,
                          padding: EdgeInsets.all(0),
                          child: Row(
                            mainAxisSize: MainAxisSize.min,
                            children: [
                              Icon(Icons.arrow_back_ios,
                                  size: 14, color: CupertinoColors.activeBlue),
                              SizedBox(
                                width: 4,
                              ),
                              Text(
                                "Edit Number",
                                style: TextStyle(
                                    color: CupertinoColors.activeBlue,
                                    fontSize: 14),
                              )
                            ],
                          ),
                        ),
                      ),
                      SizedBox(
                        height: 48,
                      ),
                      SizedBox(height: 12),
                      Form(
                        key: formKey,
                        child: GestureDetector(
                          onLongPress: () async {
                            ClipboardData clipboardData =
                                await Clipboard.getData(Clipboard.kTextPlain);
                            if (clipboardData.text != null &&
                                int.tryParse(clipboardData.text) != null) {
                              otpController.text = clipboardData.text;
                            }
                          },
                          child: PinPut(
                            fieldsCount: 6,
                            onClipboardFound: (val) {},
                            autofocus: true,
                            focusNode: focusNode,
                            onChanged: (val) {
                              setState(() {
                                otp = val;
                              });
                            },
                            controller: otpController,
                            textStyle: TextStyle(fontSize: 17),
                            submittedFieldDecoration: BoxDecoration(
                                border: Border(
                                    bottom: BorderSide(
                                        color: Colors.black, width: 1.2))),
                            disabledDecoration: BoxDecoration(
                                border: Border(
                                    bottom: BorderSide(
                                        color: Colors.black26, width: 1.2))),
                            followingFieldDecoration: BoxDecoration(
                                border: Border(
                                    bottom: BorderSide(
                                        color: Colors.black45, width: 1.2))),
                            selectedFieldDecoration: BoxDecoration(
                                border: Border(
                                    bottom: BorderSide(
                                        color: Colors.black, width: 1.2))),
                          ),
                        ),
                      ),
                      SizedBox(
                        height: 54,
                      ),
                      ContinueButton(
                          title: "Verify OTP",
                          color: Theme.of(context).primaryColor,
                          textColor: Colors.white,
                          onPressed: () {
                            if (!formKey.currentState.validate()) {
                              return;
                            }
                            widget.onVerify(otpController.text);
                          }),
                      SizedBox(
                        height: 24,
                      ),
                      CupertinoButton(
                          padding: EdgeInsets.only(right: 24),
                          minSize: 0,
                          child: Text("Resend " +
                              (counter == 0
                                  ? ""
                                  : "00:${DateHelper.convertNumberToTwo(counter)}")),
                          onPressed: counter == 0
                              ? () {
                                  resetOTP();
                                  // sendOTP();
                                  initializeTimer();
                                }
                              : null),
                      Expanded(
                        flex: 3,
                        child: Container(),
                      ),
                      Container(
                        alignment: Alignment.center,
                        child: Text(
                          "© 2020 OCG Connect Inc. All rights reserved.",
                          style: TextStyle(
                              color: Colors.black54,
                              fontSize: 15,
                              fontWeight: FontWeight.w400),
                          textAlign: TextAlign.center,
                        ),
                      ),
                      SizedBox(
                        height: 8,
                      ),
                    ],
                  ),
                ),
              ),
            )),
          ),
        ),
      ),
    );
  }

  ///
  /// Functions
  ///

  @override
  void dispose() {
    timer?.cancel();
    super.dispose();
  }
}
